@@ -121,6 +121,9 @@ class Comm(object):
             raise ValueError('Invalid keyval.')
         self._attr[keyval] = attrval
 
+    def Create_cart(self, dims, periods=None, reorder=False):
+        return Cartcomm(self.rank, self.size)
+
     @staticmethod
     def f2py(fcomm):
         return COMM_SELF
@@ -129,6 +132,11 @@ class Comm(object):
         return 0
 
 
+class Cartcomm(Comm):
+    def Sub(self, remain_dims):
+        return Comm(self.rank, self.size)
+
+
 def Get_processor_name():
     import platform
     return platform.node()
