@@ -102,7 +102,7 @@ def test_integration_trapeze():
     func_op = BlockColumnOperator([Op(_) for _ in x], new_axisout=0)
     eval_ = func_op(value)
     expected = np.trapz(eval_, x=x, axis=0)
-    integ = IntegrationTrapezeOperator(x) * func_op
+    integ = IntegrationTrapezeOperator(x)(func_op)
     assert_same(integ(value), expected)
 
 
